@@ -2,65 +2,60 @@
 from typing import Optional, Union, List
 
 from mlbstatsapi.models.teams import Team
-from mlbstatsapi.models.people import Person, Position
+from mlbstatsapi.models.people import Person, Batter, Position
 from mlbstatsapi.models.sports import Sport
 from mlbstatsapi.models.leagues import League
-from mlbstatsapi.models.game import Game
-
-
+from mlbstatsapi.models.data import CodeDesc
 
 @dataclass
-class CodeDesc:
+class PitchArsenalSplit:
+    """
+    A class to represent a pitching pitch arsenal split 
+
+    Attributes
+    ----------
+    percentage : float
+    count : int
+    totalPitches : int
+    averageSpeed : float
+    type : Union[CodeDesc, dict]
+    """
+    percentage: float
+    count: int
+    totalpitches: int
+    averagespeed: float
+    type: Union[CodeDesc, dict]
+
+@dataclass
+class ExpectedStatistics:
     """
     a class to hold a code and a description
 
     Attributes
     ----------
-    code : str
-        the pitch code to reference the pitch
-    description : str
-        the description of the pitch
     """
-    code: str
-    description: str
+    avg: str
+    slg: str
+    woba: str
+    wobacon: str
 
 @dataclass
-class Count:
+class Sabermetrics:
     """
-    a class to hold a pitch count and base runners
+    a class to hold a code and a description
 
     Attributes
     ----------
-    code : str
-        code
-    balls : int
-        number of balls
-    inning : int
-        inning number
-    istopinning : bool
-        bool to hold status of top inning
-    outs : int
-        number of outs
-    runneron1b : bool
-        bool to hold 1b runner status
-    runneron2b : bool
-        bool to hold 2b runner status
-    runneron3b : bool
-        bool to hold 3b runner status
-    strikes : int
-        strike count
     """
-    balls: int
-    inning: int
-    istopinning: bool
-    outs: int
-    runneron1b: bool
-    runneron2b: bool
-    runneron3b: bool
-    strikes: int
+    woba: float
+    wrc: float
+    wrcplus: float
+    rar: float
+    war: float
+
 
 @dataclass(kw_only=True)
-class Stats:
+class Stat:
     """
     Base class for stats
 
@@ -82,56 +77,41 @@ class Stats:
         date of game
     group : str 
         type of stat group
-    stat_group : str
+    _group : str
         type of the stat group
-    stat_type : str
+    _type : str
         type of the stat 
     """
-    stat_group: str
-    stat_type: str
-    team: Optional[Union[Team, dict]] = None
-    player: Optional[Union[Person, dict]] = None
-    sport: Optional[Union[Sport, dict]] = None
-    league: Optional[Union[League, dict]] = None
+    group: str
+    type: str
     season: Optional[str] = None
+    numteams: Optional[int] = None
+    gametype: Optional[str] = None
+    rank: Optional[int] = None
+    position: Optional[Union[Position, dict]] = field(default_factory=dict)
+    team: Optional[Union[Team, dict]] = field(default_factory=dict)
+    player: Optional[Union[Person, dict]] = field(default_factory=dict)
+    sport: Optional[Union[Sport, dict]] = field(default_factory=dict)
+    league: Optional[Union[League, dict]] = field(default_factory=dict)
+
+    def __post_init__(self):
+        self.position = Position(**self.position) if self.position else self.position
+
 
 @dataclass(kw_only=True)
-class ExpectedStatistics(Stats):
-    """
-    A class to represent a excepted statistics statType: expectedStatistics.
-    """
-    """
-    Attributes
-    ----------
-    avg : str
-    slg : str
-    woba : str
-    wobaCon : str
-    rank : int
-    """
-    type_ = [ 'expectedStatistics' ]
-    avg : str
-    slg : str
-    woba : str
-    wobaCon : str
-    season: str
-    gametype: str
-    rank : Optional[int] = None
-
-@dataclass(kw_only=True)
-class PitchArsenal(Stats):
+class PitchArsenal(Stat):
     """
     A class to represent a pitcharsenal stat for a hitter and pitcher
 
     Attributes
     ----------
     """
-    type_ = [ 'pitchArsenal' ]
-    averagespeed: float
-    count:  int
-    percentage: float
-    totalpitches: int
-    type: Union[CodeDesc, dict]
+    _stat = ['pitchArsenal']
+    stat: Union[PitchArsenalSplit, dict]
+
+    def __post_init__(self):
+        self.stat = PitchArsenalSplit(**self.stat)
+
 
 @dataclass(kw_only=True)
 class ZoneCodes:
@@ -150,12 +130,12 @@ class ZoneCodes:
         batting percentage of the zone
     """
     zone: str
-    color: str
-    temp: str
     value: str
+    color: Optional[str] = None
+    temp: Optional[str] = None
 
 @dataclass(kw_only=True)
-class HotColdZones(Stats):
+class Zones:
     """
     A class to represent a hot cold zone statistic
 
@@ -166,21 +146,72 @@ class HotColdZones(Stats):
     zones : List[ZoneCodes]
         a list of zone codes to describe the zone
     """
-    name: str 
+    name: str
     zones: List[ZoneCodes]
-    type_ = [ 'hotColdZones' ]
 
     def __post_init__(self):
-        self.zones = [ ZoneCodes(**zone) for zone in self.zones ]
+        self.zones = [ZoneCodes(**zone) for zone in self.zones]
 
 @dataclass(kw_only=True)
-class OutsAboveAverage(Stats):
+class HotColdZones(Stat):
+    """
+    A class to represent a hotcoldzone statistic
+
+    Attributes
+    ----------
+    stat : Zones
+        the holdcoldzones for the stat
+    """
+    stat: Zones
+    _stat = ['hotColdZones']
+
+    def __post_init__(self):
+        self.stat = Zones(**self.stat)
+
+@dataclass
+class Chart:
+    """
+    A class to represent a chart for SprayCharts
+
+    Attributes
+    ----------
+    leftfield : int
+        percentage
+    leftcenterfield : int
+        percentage
+    centerfield : int
+        percentage
+    rightcenterfield : int
+        percentage
+    rightfield : int
+        percentage
+    """
+    leftfield: int
+    leftcenterfield: int
+    centerfield: int
+    rightcenterfield: int
+    rightfield: int
+
+@dataclass(kw_only=True)
+class SprayCharts(Stat):
+
+
+    _stat = ['sprayChart']
+    stat: Union[Chart, dict]
+    batter: Optional[Union[Batter, dict]] = field(default_factory=dict)
+
+    def __post_init__(self):
+        self.batter = Batter(**self.batter) if self.batter else self.batter
+        self.stat = Chart(**self.stat)
+
+@dataclass(kw_only=True)
+class OutsAboveAverage(Stat):
     """
     A class to represent a outs above average statistic
 
     NOTE: This stat type returns a empty list, or keys with with the value 0
     """
-    type_ = [ 'outsAboveAverage' ]
+    _stat = ['outsAboveAverage']
     attempts: int
     totaloutsaboveaverageback: int
     totaloutsaboveaveragebackunrounded: int
@@ -199,4 +230,4 @@ class OutsAboveAverage(Stats):
     outsaboveaverageinright: int
     outsaboveaverageinrightunrounded: int
     player: Union[Person, dict]
-    gametype: str
\ No newline at end of file
+    gametype: str
